Learn R Programming

mgcv (version 1.8-2)

betar: GAM beta regression family

Description

Family for use with gam, implementing regression for beta distributed data on (0,1). A linear predictor controls the mean, $\mu$ of the beta distribution, while the variance is then $\mu(1-\mu)/(1+\phi)$, with parameter $\phi$ being estimated during fitting, alongside the smoothing parameters.

Usage

betar(theta = NULL, link = "logit")

Arguments

theta
the extra parameter ($\phi$ above).
link
The link function: one of "logit", "probit", "cloglog" and "cauchit".

Value

  • An object of class extended.family.

Details

These models are useful for proportions data which can not be modelled as binomial. Note the assumption that data are in (0,1), despite the fact that for some parameter values 0 and 1 are perfectly legitimate observations. The restriction is needed to keep the log likelihood bounded for all parameter values. Any data exactly at 0 or 1 are reset to be just above 0 or just below 1.

Examples

Run this code
library(mgcv)
## Simulate some beta data...
set.seed(3);n<-400
dat <- gamSim(1,n=n)
mu <- binomial()$linkinv(dat$f/4-2)
phi <- .5
a <- mu*phi;b <- phi - a;
dat$y <- rbeta(n,a,b) 

bm <- gam(y~s(x0)+s(x1)+s(x2)+s(x3),family=betar(link="logit"),data=dat)

bm
plot(bm,pages=1)

Run the code above in your browser using DataLab