gam have associate Predict.matrix
method functions to enable prediction from the fitted model. "Predict.matrix"(object, data)
"Predict.matrix"(object, data)
"Predict.matrix"(object, data)
"Predict.matrix"(object, data)
"Predict.matrix"(object, data)
"Predict.matrix"(object, data)
"Predict.matrix"(object, data)
"Predict.matrix"(object, data)smooth.construct method having
processed a smooth specification object generated by an s or te term in a
gam formula.smooth.construct and smooth.construct2predict.gam etc.
to predict from a fitted gam model. See Predict.matrix for more details, or the specific
smooth.construct pages for details on a particular smooth class.