mgcv works largely because many people have reported bugs over the years. If you find something that looks like a bug, please report it, so that the package can be improved. mgcv does not have a large development budget, so it is a big help if bug reports follow the following guidlines.The ideal report consists of an email to mgcv somewhere, containing
sessionInfoin the R session where the problem occurs. This provides platform details, R and package version numbers, etc.load,read.tableetc).Of course if you have dug deeper and have an idea of what is causing the problem, that is also helpful to know, as is any suggested code fix. (Don't send a fixed package .tar.gz file, however - I can't use this).