fix.family.link(fam)
fix.family.var(fam)
fix.family.ls(fam)family.dvar,
d2var, d2link, d3link, d4link and ls.If the family already has functions dvar, d2var, d3var, d2link,
d3link, d4link and for RE/ML ls, then these functions simply
return the family unmodified: this allows non-standard links
to be used with gam when using outer iteration (performance
iteration operates with unmodified families). Note that if you only need Fisher scoring then
d4link and d3var can be dummy, as they are ignored. similalry ls is only needed for
RE/ML.
The dvar function is a function of a mean vector, mu, and returns
a vector of corresponding first derivatives of the family variance
function. The d2link function is also a function of a vector of mean
values, mu: it returns a vector of second derivatives of the link,
evaluated at mu. Higher derivatives are defined similarly.
If modifying your own family, note that you can often get away with supplying
only a dvar and d2var, function if your family only requires links that occur in
one of the standard families.
gam.fit3