fix.family.link(fam)
fix.family.var(fam)family.dvar and d2link.If the family already has functions dvar and d2link then these
functions simply return the family unmodified: this allows non-standard links
to be used with gam when using outer iteration (performance
iteration operates with unmodified families).
The dvar function is a function of a mean vector, mu, and returns
a vector of corresponding first derivatives of the family variance
function. The d2link function is also a function of a vector of mean
values, mu: it returns a vector of second derivatives of the link,
evaluated at mu.
If modifying your own family, note that you can often get away with supplying
only a dvar function if your family only requires links that occur in
one of the standard families.