gam
model (note that the models are usually fitted by penalized likelihood maximization).
Used by AIC.## S3 method for class 'gam':
logLik(object,...)gam as produced by gam().logLik object: see logLik.logLik.glm which corrects the degrees of
freedom for use with gam objects. The function is provided so that AIC functions correctly with
gam objects, and uses the appropriate degrees of freedom (accounting
for penalization). Note, when using AIC for penalized models, that the
degrees of freedom are the effective degrees of freedom and not the number of
parameters, and the model maximizes the penalized likelihood, not the actual
likelihood. (See e.g. Hastie and Tibshirani, 1990, section 6.8.3 and also Wood 2008),
By default this routine uses a definition of the effective degrees of freedom that includes smoothing parameter uncertainty, if this is available (i.e. if smoothing parameter selection is by some variety of marginal likelihood).
Wood, S.N. (2008) Fast stable direct fitting and smoothness selection for generalized additive models. J.R.Statist. Soc. B 70(3):495-518
AIC